#ifndef cc1101_H
#define cc1101_H

/*{ cc1101::.h ************************************************

 Program Name: cc1101


 Copyright:    <Sascha Poggemann>. All Rights Reserved.

 Description: This is an implementation for the Texas Instruments CC1101 Tranceiver

******************************************************

 $Author: <Sascha Poggemann> $

 $Date: 2012_04_19 $
 
}*/
//{ Defines/ TypeDefs ****************************************************

//#define radio_cc1101_STM32W
//#define radio_cc1101_STM32F1x

//} Defines
//{ Includes *************************************************************

#include "cc1101_registers.h"
#include "cc1101_register_typedefs.h"

#include "ttc_basic.h"
#include "ttc_gpio.h"
#include "ttc_spi.h"


#ifdef TARGET_ARCHITECTURE_EM357
#include "stm32w108_type.h"
#include "STM32W_types_patch.h"
#include "STM32W_SPI.h"
#endif

//} Includes
//{ Structures/ Enums ****************************************************


typedef enum {   // radio_cc1101_SPIx_e
    radio_cc1101_SPI1, radio_cc1101_SPI2, radio_cc1101_SPI3
} radio_cc1101_SPIx_e;
typedef struct { // radio_cc1101_PowerStatus_t
    char * dummmy;
} radio_cc1101_PowerStatus_t;

//copied from TI example

// The following structure can be used when configuring the RF chip. SmartRF Studio
// can be used to export a predefined instance of this structure.
typedef struct { // radio_cc1101_RF_CONFIG_t
//    uint8_t fsctrl1;    // Frequency synthesizer control.
//    uint8_t fsctrl0;    // Frequency synthesizer control.
//    uint8_t freq2;      // Frequency control word, high byte.
//    uint8_t freq1;      // Frequency control word, middle byte.
//    uint8_t freq0;      // Frequency control word, low byte.
//    uint8_t mdmcfg4;    // Modem configuration.
//    uint8_t mdmcfg3;    // Modem configuration.
//    uint8_t mdmcfg2;    // Modem configuration.
//    uint8_t mdmcfg1;    // Modem configuration.
//    uint8_t mdmcfg0;    // Modem configuration.
//    uint8_t channr;     // Channel number.
//    uint8_t deviatn;    // Modem deviation setting (when FSK modulation is enabled).
//    uint8_t frend1;     // Front end RX configuration.
//    uint8_t frend0;     // Front end RX configuration.
//    uint8_t mcsm0;      // Main Radio Control State Machine configuration.
//    uint8_t foccfg;     // Frequency Offset Compensation Configuration.
//    uint8_t bscfg;      // Bit synchronization Configuration.
//    uint8_t agcctrl2;   // AGC control.
//    uint8_t agcctrl1;   // AGC control.
//    uint8_t agcctrl0;   // AGC control.
//    uint8_t fscal3;     // Frequency synthesizer calibration.
//    uint8_t fscal2;     // Frequency synthesizer calibration.
//    uint8_t fscal1;     // Frequency synthesizer calibration.
//    uint8_t fscal0;     // Frequency synthesizer calibration.
//    uint8_t fstest;     // Frequency synthesizer calibration.
//    uint8_t test2;      // Various test settings.
//    uint8_t test1;      // Various test settings.
//    uint8_t test0;      // Various test settings.
//    uint8_t iocfg2;     // GDO2 output pin configuration.
//    uint8_t iocfg0;     // GDO0 output pin configuration.
//    uint8_t pktctrl1;   // Packet automation control.
//    uint8_t pktctrl0;   // Packet automation control.
//    uint8_t addr;       // Device address.
//    uint8_t pktlen;     // Packet length.
char dummy;
} radio_cc1101_RF_CONFIG_t;

typedef struct { // radio_cc1101_Configuration_t
   radio_cc1101_RF_CONFIG_t radio_cc1101_RF_CONFIG;
    char * txpower;
    char * rxpower;
    char * modulation;
} radio_cc1101_Configuration_t;

//// For rapid chip configuration with a minimum of function overhead.
//// The array has to be set up with predefined values for all registers.
//typedef uint8_t radio_cc1101_RF_BURST_CONFIG[47];

//// The chip status byte, returned by chip for all SPI accesses
//typedef uint8_t radio_cc1101_RF_STATUS;

//} Structures/ Enums
//{ Function prototypes **************************************************

void radio_cc1101_Init(radio_cc1101_SPIx_e SPIx);
void radio_cc1101_Configure(radio_cc1101_Configuration_t radio_cc1101_Configuration);
radio_cc1101_PowerStatus_t radio_cc1101_PowerStatus_get(void);
void radio_cc1101_PowerStatus_set(radio_cc1101_PowerStatus_t radio_cc1101_PowerStatus);
void radio_cc1101_Register_set(u8_t addr, u8_t * data);
void radio_cc1101_Register_get(u8_t addr, u8_t * data);
void radio_cc1101_receive_data(u8_t addr, u8_t * data, u32_t length);
void radio_cc1101_send_data(const char * data, u32_t length);
void radio_cc1101_receive_data_ISR_Handler(void);


//copied from TI example
//void  halRfConfig(const HAL_RF_CONFIG* rfConfig, const uint8_t* rfPaTable, uint8_t rfPaTableLen);
//void  halRfBurstConfig(const HAL_RF_BURST_CONFIG rfConfig, const uint8_t* rfPaTable, uint8_t rfPaTableLen);


//} Function prototypes

#endif //cc1101_H
